module.exports = defineTest({
	description: 'treat getters and setters on classes as function calls'
});
